@@ -177,322 +177,332 @@ pub const SAMPLE_MODEL_JSON: &str = r#"
         }
     },
     "cgroup": {
-        "name": "<root>",
-        "full_path": "",
-        "inode_number": 1,
-        "depth": 0,
-        "cpu": null,
-        "memory": {
-            "total": 5000000000,
-            "swap": 1000000000,
-            "anon": 2000000000,
-            "file": 2000000000,
-            "kernel_stack": 40000000,
-            "slab": 300000000,
-            "sock": 10000000,
-            "shmem": 2000000,
-            "file_mapped": 200000000,
-            "file_dirty": 3000000,
-            "file_writeback": 60000000,
-            "anon_thp": 10000000,
-            "inactive_anon": 500000000,
-            "active_anon": 2000000000,
-            "inactive_file": 900000000,
-            "active_file": 1000000000,
-            "unevictable": 5000000,
-            "slab_reclaimable": 200000000,
-            "slab_unreclaimable": 100000000,
-            "pgfault": 3000,
-            "pgmajfault": 100,
-            "workingset_refault": 3000,
-            "workingset_activate": 2000,
-            "workingset_nodereclaim": 0,
-            "pgrefill": 0,
-            "pgscan": 0,
-            "pgsteal": 0,
-            "pgactivate": 0,
-            "pgdeactivate": 0,
-            "pglazyfree": 0,
-            "pglazyfreed": 0,
-            "thp_fault_alloc": 0,
-            "thp_collapse_alloc": 0,
-            "memory_high": null,
-            "events_low": 0,
-            "events_high": 300000,
-            "events_max": 300000,
-            "events_oom": 0,
-            "events_oom_kill": 0
-        },
-        "io": null,
-        "io_total": null,
-        "pressure": {
-            "cpu_some_pct": 2.05,
-            "io_some_pct": 0.8,
-            "io_full_pct": 0.7,
-            "memory_some_pct": 0.6,
-            "memory_full_pct": 0.3
+        "data": {
+            "name": "<root>",
+            "full_path": "",
+            "inode_number": 1,
+            "depth": 0,
+            "cpu": null,
+            "memory": {
+                "total": 5000000000,
+                "swap": 1000000000,
+                "anon": 2000000000,
+                "file": 2000000000,
+                "kernel_stack": 40000000,
+                "slab": 300000000,
+                "sock": 10000000,
+                "shmem": 2000000,
+                "file_mapped": 200000000,
+                "file_dirty": 3000000,
+                "file_writeback": 60000000,
+                "anon_thp": 10000000,
+                "inactive_anon": 500000000,
+                "active_anon": 2000000000,
+                "inactive_file": 900000000,
+                "active_file": 1000000000,
+                "unevictable": 5000000,
+                "slab_reclaimable": 200000000,
+                "slab_unreclaimable": 100000000,
+                "pgfault": 3000,
+                "pgmajfault": 100,
+                "workingset_refault": 3000,
+                "workingset_activate": 2000,
+                "workingset_nodereclaim": 0,
+                "pgrefill": 0,
+                "pgscan": 0,
+                "pgsteal": 0,
+                "pgactivate": 0,
+                "pgdeactivate": 0,
+                "pglazyfree": 0,
+                "pglazyfreed": 0,
+                "thp_fault_alloc": 0,
+                "thp_collapse_alloc": 0,
+                "memory_high": null,
+                "events_low": 0,
+                "events_high": 300000,
+                "events_max": 300000,
+                "events_oom": 0,
+                "events_oom_kill": 0
+            },
+            "io": null,
+            "io_total": null,
+            "pressure": {
+                "cpu_some_pct": 2.05,
+                "io_some_pct": 0.8,
+                "io_full_pct": 0.7,
+                "memory_some_pct": 0.6,
+                "memory_full_pct": 0.3
+            }
         },
         "children": [
             {
-                "name": "init.scope",
-                "full_path": "/init.scope",
-                "inode_number": 17,
-                "depth": 1,
-                "cpu": {
-                    "usage_pct": 0.01000,
-                    "user_pct": 0.00900,
-                    "system_pct": 0.00400,
-                    "nr_periods_per_sec": 0.0,
-                    "nr_throttled_per_sec": 0.0,
-                    "throttled_pct": 0.0
-                },
-                "memory": {
-                    "total": 20000000,
-                    "swap": 5000000,
-                    "anon": 6000000,
-                    "file": 10000000,
-                    "kernel_stack": 1000000,
-                    "slab": 5000000,
-                    "sock": 0,
-                    "shmem": 30000,
-                    "file_mapped": 7000000,
-                    "file_dirty": 0,
-                    "file_writeback": 800000,
-                    "anon_thp": 0,
-                    "inactive_anon": 3000000,
-                    "active_anon": 3000000,
-                    "inactive_file": 600000,
-                    "active_file": 6000000,
-                    "unevictable": 4000000,
-                    "slab_reclaimable": 3000000,
-                    "slab_unreclaimable": 2000000,
-                    "pgfault": 0,
-                    "pgmajfault": 0,
-                    "workingset_refault": 0,
-                    "workingset_activate": 0,
-                    "workingset_nodereclaim": 0,
-                    "pgrefill": 0,
-                    "pgscan": 0,
-                    "pgsteal": 0,
-                    "pgactivate": 0,
-                    "pgdeactivate": 0,
-                    "pglazyfree": 0,
-                    "pglazyfreed": 0,
-                    "thp_fault_alloc": 0,
-                    "thp_collapse_alloc": 0,
-                    "memory_high": -1,
-                    "events_low": 0,
-                    "events_high": 0,
-                    "events_max": 0,
-                    "events_oom": 0,
-                    "events_oom_kill": 0
-                },
-                "io": null,
-                "io_total": null,
-                "pressure": {
-                    "cpu_some_pct": 0.0,
-                    "io_some_pct": 0.0,
-                    "io_full_pct": 0.0,
-                    "memory_some_pct": 0.0,
-                    "memory_full_pct": 0.0
+                "data": {
+                    "name": "init.scope",
+                    "full_path": "/init.scope",
+                    "inode_number": 17,
+                    "depth": 1,
+                    "cpu": {
+                        "usage_pct": 0.01000,
+                        "user_pct": 0.00900,
+                        "system_pct": 0.00400,
+                        "nr_periods_per_sec": 0.0,
+                        "nr_throttled_per_sec": 0.0,
+                        "throttled_pct": 0.0
+                    },
+                    "memory": {
+                        "total": 20000000,
+                        "swap": 5000000,
+                        "anon": 6000000,
+                        "file": 10000000,
+                        "kernel_stack": 1000000,
+                        "slab": 5000000,
+                        "sock": 0,
+                        "shmem": 30000,
+                        "file_mapped": 7000000,
+                        "file_dirty": 0,
+                        "file_writeback": 800000,
+                        "anon_thp": 0,
+                        "inactive_anon": 3000000,
+                        "active_anon": 3000000,
+                        "inactive_file": 600000,
+                        "active_file": 6000000,
+                        "unevictable": 4000000,
+                        "slab_reclaimable": 3000000,
+                        "slab_unreclaimable": 2000000,
+                        "pgfault": 0,
+                        "pgmajfault": 0,
+                        "workingset_refault": 0,
+                        "workingset_activate": 0,
+                        "workingset_nodereclaim": 0,
+                        "pgrefill": 0,
+                        "pgscan": 0,
+                        "pgsteal": 0,
+                        "pgactivate": 0,
+                        "pgdeactivate": 0,
+                        "pglazyfree": 0,
+                        "pglazyfreed": 0,
+                        "thp_fault_alloc": 0,
+                        "thp_collapse_alloc": 0,
+                        "memory_high": -1,
+                        "events_low": 0,
+                        "events_high": 0,
+                        "events_max": 0,
+                        "events_oom": 0,
+                        "events_oom_kill": 0
+                    },
+                    "io": null,
+                    "io_total": null,
+                    "pressure": {
+                        "cpu_some_pct": 0.0,
+                        "io_some_pct": 0.0,
+                        "io_full_pct": 0.0,
+                        "memory_some_pct": 0.0,
+                        "memory_full_pct": 0.0
+                    }
                 },
                 "children": [],
                 "count": 1,
                 "recreate_flag": false
             },
             {
-                "name": "child_a.slice",
-                "full_path": "/child_a.slice",
-                "inode_number": 11111,
-                "depth": 1,
-                "cpu": {
-                    "usage_pct": 0.0,
-                    "user_pct": 0.0,
-                    "system_pct": 0.0,
-                    "nr_periods_per_sec": 0.0,
-                    "nr_throttled_per_sec": 0.0,
-                    "throttled_pct": 0.0
-                },
-                "memory": {
-                    "total": 8000,
-                    "swap": 0,
-                    "anon": 0,
-                    "file": 0,
-                    "kernel_stack": 0,
-                    "slab": 3000000,
-                    "sock": 0,
-                    "shmem": 0,
-                    "file_mapped": 0,
-                    "file_dirty": 0,
-                    "file_writeback": 0,
-                    "anon_thp": 0,
-                    "inactive_anon": 0,
-                    "active_anon": 0,
-                    "inactive_file": 0,
-                    "active_file": 0,
-                    "unevictable": 0,
-                    "slab_reclaimable": 1000000,
-                    "slab_unreclaimable": 1000000,
-                    "pgfault": 0,
-                    "pgmajfault": 0,
-                    "workingset_refault": 0,
-                    "workingset_activate": 0,
-                    "workingset_nodereclaim": 0,
-                    "pgrefill": 0,
-                    "pgscan": 0,
-                    "pgsteal": 0,
-                    "pgactivate": 0,
-                    "pgdeactivate": 0,
-                    "pglazyfree": 0,
-                    "pglazyfreed": 0,
-                    "thp_fault_alloc": 0,
-                    "thp_collapse_alloc": 0,
-                    "memory_high": -1,
-                    "events_low": 0,
-                    "events_high": 0,
-                    "events_max": 0,
-                    "events_oom": 0,
-                    "events_oom_kill": 0
-                },
-                "io": null,
-                "io_total": null,
-                "pressure": {
-                    "cpu_some_pct": 0.0,
-                    "io_some_pct": 0.0,
-                    "io_full_pct": 0.0,
-                    "memory_some_pct": 0.0,
-                    "memory_full_pct": 0.0
+                "data": {
+                    "name": "child_a.slice",
+                    "full_path": "/child_a.slice",
+                    "inode_number": 11111,
+                    "depth": 1,
+                    "cpu": {
+                        "usage_pct": 0.0,
+                        "user_pct": 0.0,
+                        "system_pct": 0.0,
+                        "nr_periods_per_sec": 0.0,
+                        "nr_throttled_per_sec": 0.0,
+                        "throttled_pct": 0.0
+                    },
+                    "memory": {
+                        "total": 8000,
+                        "swap": 0,
+                        "anon": 0,
+                        "file": 0,
+                        "kernel_stack": 0,
+                        "slab": 3000000,
+                        "sock": 0,
+                        "shmem": 0,
+                        "file_mapped": 0,
+                        "file_dirty": 0,
+                        "file_writeback": 0,
+                        "anon_thp": 0,
+                        "inactive_anon": 0,
+                        "active_anon": 0,
+                        "inactive_file": 0,
+                        "active_file": 0,
+                        "unevictable": 0,
+                        "slab_reclaimable": 1000000,
+                        "slab_unreclaimable": 1000000,
+                        "pgfault": 0,
+                        "pgmajfault": 0,
+                        "workingset_refault": 0,
+                        "workingset_activate": 0,
+                        "workingset_nodereclaim": 0,
+                        "pgrefill": 0,
+                        "pgscan": 0,
+                        "pgsteal": 0,
+                        "pgactivate": 0,
+                        "pgdeactivate": 0,
+                        "pglazyfree": 0,
+                        "pglazyfreed": 0,
+                        "thp_fault_alloc": 0,
+                        "thp_collapse_alloc": 0,
+                        "memory_high": -1,
+                        "events_low": 0,
+                        "events_high": 0,
+                        "events_max": 0,
+                        "events_oom": 0,
+                        "events_oom_kill": 0
+                    },
+                    "io": null,
+                    "io_total": null,
+                    "pressure": {
+                        "cpu_some_pct": 0.0,
+                        "io_some_pct": 0.0,
+                        "io_full_pct": 0.0,
+                        "memory_some_pct": 0.0,
+                        "memory_full_pct": 0.0
+                    }
                 },
                 "children": [],
                 "count": 1,
                 "recreate_flag": false
             },
             {
-                "name": "child_b.slice",
-                "full_path": "/child_b.slice",
-                "inode_number": 1111,
-                "depth": 1,
-                "cpu": {
-                    "usage_pct": 3.5,
-                    "user_pct": 3.5,
-                    "system_pct": 0.0,
-                    "nr_periods_per_sec": 0.0,
-                    "nr_throttled_per_sec": 0.0,
-                    "throttled_pct": 0.0
-                },
-                "memory": {
-                    "total": 30000000,
-                    "swap": 9000000,
-                    "anon": 8000000,
-                    "file": 20000000,
-                    "kernel_stack": 800000,
-                    "slab": 3000000,
-                    "sock": 400000,
-                    "shmem": 1000000,
-                    "file_mapped": 50000000,
-                    "file_dirty": 1000000,
-                    "file_writeback": 9000000,
-                    "anon_thp": 0,
-                    "inactive_anon": 60000000,
-                    "active_anon": 40000000,
-                    "inactive_file": 70000000,
-                    "active_file": 100000000,
-                    "unevictable": 0,
-                    "slab_reclaimable": 20000000,
-                    "slab_unreclaimable": 10000000,
-                    "pgfault": 10,
-                    "pgmajfault": 0,
-                    "workingset_refault": 0,
-                    "workingset_activate": 0,
-                    "workingset_nodereclaim": 0,
-                    "pgrefill": 0,
-                    "pgscan": 0,
-                    "pgsteal": 0,
-                    "pgactivate": 0,
-                    "pgdeactivate": 0,
-                    "pglazyfree": 0,
-                    "pglazyfreed": 0,
-                    "thp_fault_alloc": 0,
-                    "thp_collapse_alloc": 0,
-                    "memory_high": -1,
-                    "events_low": 0,
-                    "events_high": 0,
-                    "events_max": 0,
-                    "events_oom": 0,
-                    "events_oom_kill": 0
-                },
-                "io": null,
-                "io_total": null,
-                "pressure": {
-                    "cpu_some_pct": 0.15,
-                    "io_some_pct": 0.0,
-                    "io_full_pct": 0.0,
-                    "memory_some_pct": 0.0,
-                    "memory_full_pct": 0.0
+                "data": {
+                    "name": "child_b.slice",
+                    "full_path": "/child_b.slice",
+                    "inode_number": 1111,
+                    "depth": 1,
+                    "cpu": {
+                        "usage_pct": 3.5,
+                        "user_pct": 3.5,
+                        "system_pct": 0.0,
+                        "nr_periods_per_sec": 0.0,
+                        "nr_throttled_per_sec": 0.0,
+                        "throttled_pct": 0.0
+                    },
+                    "memory": {
+                        "total": 30000000,
+                        "swap": 9000000,
+                        "anon": 8000000,
+                        "file": 20000000,
+                        "kernel_stack": 800000,
+                        "slab": 3000000,
+                        "sock": 400000,
+                        "shmem": 1000000,
+                        "file_mapped": 50000000,
+                        "file_dirty": 1000000,
+                        "file_writeback": 9000000,
+                        "anon_thp": 0,
+                        "inactive_anon": 60000000,
+                        "active_anon": 40000000,
+                        "inactive_file": 70000000,
+                        "active_file": 100000000,
+                        "unevictable": 0,
+                        "slab_reclaimable": 20000000,
+                        "slab_unreclaimable": 10000000,
+                        "pgfault": 10,
+                        "pgmajfault": 0,
+                        "workingset_refault": 0,
+                        "workingset_activate": 0,
+                        "workingset_nodereclaim": 0,
+                        "pgrefill": 0,
+                        "pgscan": 0,
+                        "pgsteal": 0,
+                        "pgactivate": 0,
+                        "pgdeactivate": 0,
+                        "pglazyfree": 0,
+                        "pglazyfreed": 0,
+                        "thp_fault_alloc": 0,
+                        "thp_collapse_alloc": 0,
+                        "memory_high": -1,
+                        "events_low": 0,
+                        "events_high": 0,
+                        "events_max": 0,
+                        "events_oom": 0,
+                        "events_oom_kill": 0
+                    },
+                    "io": null,
+                    "io_total": null,
+                    "pressure": {
+                        "cpu_some_pct": 0.15,
+                        "io_some_pct": 0.0,
+                        "io_full_pct": 0.0,
+                        "memory_some_pct": 0.0,
+                        "memory_full_pct": 0.0
+                    }
                 },
                 "children": [
                     {
-                        "name": "something.service",
-                        "full_path": "/child_b.slice/something.service",
-                        "inode_number": 11111111,
-                        "depth": 2,
-                        "cpu": {
-                            "usage_pct": 0.6,
-                            "user_pct": 0.1,
-                            "system_pct": 0.5,
-                            "nr_periods_per_sec": null,
-                            "nr_throttled_per_sec": null,
-                            "throttled_pct": null
-                        },
-                        "memory": {
-                            "total": 500000,
-                            "swap": 0,
-                            "anon": 100000,
-                            "file": 200000,
-                            "kernel_stack": 30000,
-                            "slab": 200000,
-                            "sock": 0,
-                            "shmem": 0,
-                            "file_mapped": 200000,
-                            "file_dirty": 0,
-                            "file_writeback": 0,
-                            "anon_thp": 0,
-                            "inactive_anon": 0,
-                            "active_anon": 100000,
-                            "inactive_file": 20000,
-                            "active_file": 200000,
-                            "unevictable": 0,
-                            "slab_reclaimable": 70000,
-                            "slab_unreclaimable": 100000,
-                            "pgfault": 0,
-                            "pgmajfault": 0,
-                            "workingset_refault": 0,
-                            "workingset_activate": 0,
-                            "workingset_nodereclaim": 0,
-                            "pgrefill": 0,
-                            "pgscan": 0,
-                            "pgsteal": 0,
-                            "pgactivate": 0,
-                            "pgdeactivate": 0,
-                            "pglazyfree": 0,
-                            "pglazyfreed": 0,
-                            "thp_fault_alloc": 0,
-                            "thp_collapse_alloc": 0,
-                            "memory_high": -1,
-                            "events_low": 0,
-                            "events_high": 0,
-                            "events_max": 0,
-                            "events_oom": 0,
-                            "events_oom_kill": 0
-                        },
-                        "io": null,
-                        "io_total": null,
-                        "pressure": {
-                            "cpu_some_pct": 0.0,
-                            "io_some_pct": 0.0,
-                            "io_full_pct": 0.0,
-                            "memory_some_pct": 0.0,
-                            "memory_full_pct": 0.0
+                        "data": {
+                            "name": "something.service",
+                            "full_path": "/child_b.slice/something.service",
+                            "inode_number": 11111111,
+                            "depth": 2,
+                            "cpu": {
+                                "usage_pct": 0.6,
+                                "user_pct": 0.1,
+                                "system_pct": 0.5,
+                                "nr_periods_per_sec": null,
+                                "nr_throttled_per_sec": null,
+                                "throttled_pct": null
+                            },
+                            "memory": {
+                                "total": 500000,
+                                "swap": 0,
+                                "anon": 100000,
+                                "file": 200000,
+                                "kernel_stack": 30000,
+                                "slab": 200000,
+                                "sock": 0,
+                                "shmem": 0,
+                                "file_mapped": 200000,
+                                "file_dirty": 0,
+                                "file_writeback": 0,
+                                "anon_thp": 0,
+                                "inactive_anon": 0,
+                                "active_anon": 100000,
+                                "inactive_file": 20000,
+                                "active_file": 200000,
+                                "unevictable": 0,
+                                "slab_reclaimable": 70000,
+                                "slab_unreclaimable": 100000,
+                                "pgfault": 0,
+                                "pgmajfault": 0,
+                                "workingset_refault": 0,
+                                "workingset_activate": 0,
+                                "workingset_nodereclaim": 0,
+                                "pgrefill": 0,
+                                "pgscan": 0,
+                                "pgsteal": 0,
+                                "pgactivate": 0,
+                                "pgdeactivate": 0,
+                                "pglazyfree": 0,
+                                "pglazyfreed": 0,
+                                "thp_fault_alloc": 0,
+                                "thp_collapse_alloc": 0,
+                                "memory_high": -1,
+                                "events_low": 0,
+                                "events_high": 0,
+                                "events_max": 0,
+                                "events_oom": 0,
+                                "events_oom_kill": 0
+                            },
+                            "io": null,
+                            "io_total": null,
+                            "pressure": {
+                                "cpu_some_pct": 0.0,
+                                "io_some_pct": 0.0,
+                                "io_full_pct": 0.0,
+                                "memory_some_pct": 0.0,
+                                "memory_full_pct": 0.0
+                            }
                         },
                         "children": [],
                         "count": 1,
